@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "dashboard" "20260221.1336"
+(define-package "dashboard" "20260228.1548"
   "A startup screen extracted from Spacemacs."
   '((emacs "27.1"))
-  :url "https://github.com/emacs-dashboard/emacs-dashboard"
-  :commit "13fa459e8d60b83ff6134486d44888e3bdcf291a"
-  :revdesc "13fa459e8d60"
+  :url "https://github.com/emacs-dashboard/dashboard"
+  :commit "64494b6e5d9359586ba17efcebdea62f1992a808"
+  :revdesc "64494b6e5d93"
   :keywords '("startup" "screen" "tools" "dashboard")
   :authors '(("Rakan Al-Hneiti" . "rakan.alhneiti@gmail.com"))
   :maintainers '(("Jen-Chieh" . "jcs090218@gmail.com")
