@@ -5,15 +5,15 @@
 ;; Author     : Rakan Al-Hneiti <rakan.alhneiti@gmail.com>
 ;; Maintainer : Shen, Jen-Chieh <jcs090218@gmail.com>
 ;;              Ricardo Arredondo <ricardo.richo@gmail.com>
-;; URL        : https://github.com/emacs-dashboard/emacs-dashboard
+;; URL        : https://github.com/emacs-dashboard/dashboard
 ;;
 ;; This file is not part of GNU Emacs.
 ;;
 ;;; License: GPLv3
 ;;
 ;; Created: October 05, 2016
-;; Package-Version: 20260221.1336
-;; Package-Revision: 13fa459e8d60
+;; Package-Version: 20260228.1548
+;; Package-Revision: 64494b6e5d93
 ;; Keywords: startup, screen, tools, dashboard
 ;; Package-Requires: ((emacs "27.1"))
 
@@ -529,7 +529,9 @@ See `dashboard-item-generators' for all items available."
   "Insert the list of widgets into the buffer, FORCE-REFRESH is optional."
   (interactive)
   (let ((inhibit-redisplay t)
-        (recentf-is-on (recentf-enabled-p))
+        (recentf-is-on (or (recentf-enabled-p)
+                           (and (assq 'recents dashboard-items)
+                                (dashboard-mute-apply (recentf-mode 1)))))
         (origial-recentf-list recentf-list)
         (dashboard-num-recents (or (cdr (assoc 'recents dashboard-items)) 0)))
     (when recentf-is-on
